==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkAngleRepresentation3D.java <==
// java wrapper for vtkAngleRepresentation3D object
//

package vtk;
import vtk.*;

public class vtkAngleRepresentation3D extends vtkAngleRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double GetAngle_2();
  public double GetAngle()
    { return GetAngle_2(); }

  private native void GetPoint1WorldPosition_3(double id0[]);
  public void GetPoint1WorldPosition(double id0[])
    { GetPoint1WorldPosition_3(id0); }

  private native void GetCenterWorldPosition_4(double id0[]);
  public void GetCenterWorldPosition(double id0[])
    { GetCenterWorldPosition_4(id0); }

  private native void GetPoint2WorldPosition_5(double id0[]);
  public void GetPoint2WorldPosition(double id0[])
    { GetPoint2WorldPosition_5(id0); }

  private native void SetPoint1WorldPosition_6(double id0[]);
  public void SetPoint1WorldPosition(double id0[])
    { SetPoint1WorldPosition_6(id0); }

  private native void SetPoint1DisplayPosition_7(double id0[]);
  public void SetPoint1DisplayPosition(double id0[])
    { SetPoint1DisplayPosition_7(id0); }

  private native void SetCenterWorldPosition_8(double id0[]);
  public void SetCenterWorldPosition(double id0[])
    { SetCenterWorldPosition_8(id0); }

  private native void SetCenterDisplayPosition_9(double id0[]);
  public void SetCenterDisplayPosition(double id0[])
    { SetCenterDisplayPosition_9(id0); }

  private native void SetPoint2WorldPosition_10(double id0[]);
  public void SetPoint2WorldPosition(double id0[])
    { SetPoint2WorldPosition_10(id0); }

  private native void SetPoint2DisplayPosition_11(double id0[]);
  public void SetPoint2DisplayPosition(double id0[])
    { SetPoint2DisplayPosition_11(id0); }

  private native void GetPoint1DisplayPosition_12(double id0[]);
  public void GetPoint1DisplayPosition(double id0[])
    { GetPoint1DisplayPosition_12(id0); }

  private native void GetCenterDisplayPosition_13(double id0[]);
  public void GetCenterDisplayPosition(double id0[])
    { GetCenterDisplayPosition_13(id0); }

  private native void GetPoint2DisplayPosition_14(double id0[]);
  public void GetPoint2DisplayPosition(double id0[])
    { GetPoint2DisplayPosition_14(id0); }

  private native long GetRay1_15();
  public vtkActor GetRay1() {
    long temp = GetRay1_15();

    if (temp == 0) return null;
    return (vtkActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetRay2_16();
  public vtkActor GetRay2() {
    long temp = GetRay2_16();

    if (temp == 0) return null;
    return (vtkActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetArc_17();
  public vtkActor GetArc() {
    long temp = GetArc_17();

    if (temp == 0) return null;
    return (vtkActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetTextActor_18();
  public vtkFollower GetTextActor() {
    long temp = GetTextActor_18();

    if (temp == 0) return null;
    return (vtkFollower)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetTextActorScale_19(double id0[]);
  public void SetTextActorScale(double id0[])
    { SetTextActorScale_19(id0); }

  private native void BuildRepresentation_20();
  public void BuildRepresentation()
    { BuildRepresentation_20(); }

  private native void ReleaseGraphicsResources_21(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_21(id0); }

  private native int RenderOpaqueGeometry_22(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_22(id0); }

  private native int RenderTranslucentPolygonalGeometry_23(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_23(id0); }

  private native int HasTranslucentPolygonalGeometry_24();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_24(); }

  public vtkAngleRepresentation3D() { super(); }

  public vtkAngleRepresentation3D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-1-aarch64.pkg.tar.xz: vtk/vtkAngleRepresentation3D.java <==
// java wrapper for vtkAngleRepresentation3D object
//

package vtk;
import vtk.*;

public class vtkAngleRepresentation3D extends vtkAngleRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double GetAngle_2();
  public double GetAngle()
    { return GetAngle_2(); }

  private native void GetPoint1WorldPosition_3(double id0[]);
  public void GetPoint1WorldPosition(double id0[])
    { GetPoint1WorldPosition_3(id0); }

  private native void GetCenterWorldPosition_4(double id0[]);
  public void GetCenterWorldPosition(double id0[])
    { GetCenterWorldPosition_4(id0); }

  private native void GetPoint2WorldPosition_5(double id0[]);
  public void GetPoint2WorldPosition(double id0[])
    { GetPoint2WorldPosition_5(id0); }

  private native void SetPoint1WorldPosition_6(double id0[]);
  public void SetPoint1WorldPosition(double id0[])
    { SetPoint1WorldPosition_6(id0); }

  private native void SetPoint1DisplayPosition_7(double id0[]);
  public void SetPoint1DisplayPosition(double id0[])
    { SetPoint1DisplayPosition_7(id0); }

  private native void SetCenterWorldPosition_8(double id0[]);
  public void SetCenterWorldPosition(double id0[])
    { SetCenterWorldPosition_8(id0); }

  private native void SetCenterDisplayPosition_9(double id0[]);
  public void SetCenterDisplayPosition(double id0[])
    { SetCenterDisplayPosition_9(id0); }

  private native void SetPoint2WorldPosition_10(double id0[]);
  public void SetPoint2WorldPosition(double id0[])
    { SetPoint2WorldPosition_10(id0); }

  private native void SetPoint2DisplayPosition_11(double id0[]);
  public void SetPoint2DisplayPosition(double id0[])
    { SetPoint2DisplayPosition_11(id0); }

  private native void GetPoint1DisplayPosition_12(double id0[]);
  public void GetPoint1DisplayPosition(double id0[])
    { GetPoint1DisplayPosition_12(id0); }

  private native void GetCenterDisplayPosition_13(double id0[]);
  public void GetCenterDisplayPosition(double id0[])
    { GetCenterDisplayPosition_13(id0); }

  private native void GetPoint2DisplayPosition_14(double id0[]);
  public void GetPoint2DisplayPosition(double id0[])
    { GetPoint2DisplayPosition_14(id0); }

  private native long GetRay1_15();
  public vtkActor GetRay1() {
    long temp = GetRay1_15();

    if (temp == 0) return null;
    return (vtkActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRay2_16();
  public vtkActor GetRay2() {
    long temp = GetRay2_16();

    if (temp == 0) return null;
    return (vtkActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetArc_17();
  public vtkActor GetArc() {
    long temp = GetArc_17();

    if (temp == 0) return null;
    return (vtkActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTextActor_18();
  public vtkFollower GetTextActor() {
    long temp = GetTextActor_18();

    if (temp == 0) return null;
    return (vtkFollower)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTextActorScale_19(double id0[]);
  public void SetTextActorScale(double id0[])
    { SetTextActorScale_19(id0); }

  private native void BuildRepresentation_20();
  public void BuildRepresentation()
    { BuildRepresentation_20(); }

  private native void ReleaseGraphicsResources_21(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_21(id0); }

  private native int RenderOpaqueGeometry_22(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_22(id0); }

  private native int RenderTranslucentPolygonalGeometry_23(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_23(id0); }

  private native int HasTranslucentPolygonalGeometry_24();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_24(); }

  public vtkAngleRepresentation3D() { super(); }

  public vtkAngleRepresentation3D(long id) { super(id); }
  public native long   VTKInit();

}
